@@ -62,7 +62,7 @@ use MIME::Base64;
 BEGIN {
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION     = '0.01';
+    $VERSION     = '0.02';
     @ISA         = qw(Exporter);
     #Give a hoot don't pollute, do not export more than needed by default
     @EXPORT      = qw();
@@ -634,6 +634,14 @@ sub _received { $_[0] = $_ unless defined $_[0]; _debug "<<< $_[0]"; }
 # ######################################################################
 # minor public routines
 
+=head1 Minor public methods
+
+=head2 ssend
+
+ Usage : $self->ssend("GETSCRIPT \"$name\"");
+
+=cut
+
 sub ssend
 {
         my $self = shift;
@@ -653,6 +661,17 @@ sub ssend
         }
 }
 
+=head2 sget
+
+ Usage: 
+    $self->sget();
+    unless (/^OK((?:\s.*)?)$/) {
+        warn "SETACTIVE($name) failed: $_\n";
+        return 0;
+    }
+
+=cut
+
 sub sget
 {
         my $self = shift;
@@ -686,6 +705,12 @@ sub sget
         }
 }
 
+=head2 sfinish
+
+send LOGOUT
+
+=cut
+
 sub sfinish
 {
         my $self = shift;
@@ -698,6 +723,12 @@ sub sfinish
         $self->sget();
 }
 
+=head2 closedie
+
+send LOGOUT and die
+
+=cut
+
 sub closedie
 {
         my $self = shift;
@@ -708,6 +739,12 @@ sub closedie
         die @_;
 }
 
+=head2 closedie_NOmsg
+
+closedie whitout message
+
+=cut
+
 sub closedie_NOmsg
 {
         my $self = shift;
@@ -721,6 +758,12 @@ sub closedie_NOmsg
         $self->closedie($_[0] . $suffix . "\n");
 }
 
+=head2 die_NOmsg
+
+die
+
+=cut
+
 sub die_NOmsg
 {
         my $suffix = shift;
@@ -734,8 +777,6 @@ sub die_NOmsg
 }
 
 
-#################### main pod documentation begin ###################
-
 =head1 BUGS
 
 I don't try plain text or client certificate authentification. 
